<?php declare (strict_types=1);

namespace Infomaker\Everyware\NewsML;

use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\Support\NewRelicLog;
use Infomaker\Everyware\NewsML\Parsers\IdfParser;
use Exception;
use SimpleXMLIterator;

class NewsMLTransformer
{

    public const VALID_TAG_IDF = 'idf';
    public const VALID_TAG_OBJECT = 'object';
    public const VALID_TAG_META = 'metadata';

    /**
     * @var IdfParser
     */
    private $parser;

    public function __construct(ItemParser $parser)
    {
        $this->parser = $parser;
    }

    public function transform(string $newsml): array
    {
        try {
            $iterator = new SimpleXMLIterator($newsml);

            if ($this->isValidTag($iterator->getName())) {
                return $this->parser->parse($iterator);
            }

        } catch (Exception $exception) {
            NewRelicLog::error(sprintf('Failed parsing NewsML from %s', $newsml), $exception);
        }

        return [];
    }

    private function isValidTag($tag): bool
    {
        return in_array($tag, [static::VALID_TAG_IDF, static::VALID_TAG_OBJECT, static::VALID_TAG_META], true);
    }
}
