<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use SimpleXMLIterator;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;

/**
 * GroupParser
 * @package Infomaker\Everyware\NewsML\Parsers
 */
class GroupParser implements ItemParser
{

    public const TAG = 'group';

    /**
     * @var ItemParser[]
     */
    private $parsers;

    public function __construct(ElementParser $elementParser, ObjectParser $objectParser)
    {
        $this->parsers = [
            ElementParser::TAG => $elementParser,
            ObjectParser::TAG => $objectParser,
            self::TAG => $this
        ];
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $items = [];
        foreach ($element as $tag => $item) {
            $parser = $this->parsers[$tag] ?? null;

            if ($parser instanceof ItemParser) {
                $items[] = $parser->parse($item);
            }
        }

        return array_merge(...$items);
    }
}
