<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\LinkParsers\InstagramLinkParser;
use Infomaker\Everyware\NewsML\LinkParsers\TwitterLinkParser;
use Infomaker\Everyware\NewsML\Parsers\LinkParser;
use PhpSpec\ObjectBehavior;

class LinkParserSpec extends ObjectBehavior
{
    private $parsers;

    public function let()
    {
        $this->parsers = ['x-im/instagram' => new InstagramLinkParser(), 'x-im/tweet' => new TwitterLinkParser()];
        $this->beConstructedWith($this->parsers);
    }

    function it_is_initializable()
    {
        $this->shouldHaveType(LinkParser::class);
    }

    public function it_can_pass_parsers()
    {
        $this->beConstructedWith([]);
        $this->shouldHaveType(LinkParser::class);
    }

    public function it_can_get_a_link_parser()
    {
        $xml = '<link type="x-im/instagram" url="testat">test</link>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->getLinkParser($el)
            ->shouldReturn($this->parsers['x-im/instagram']);
    }

    public function it_can_parse_links()
    {
        $xml = <<<XML
<xml>
    <links>
        <link type="x-im/instagram" url="https://www.instagram.com/p/BmPMCR3HLii/">test</link>
        <link type="x-im/unknown" url="https://www.instagram.com/p/BmPMCR3HLii/">test</link>
    </links>
</xml>
XML;
        $this->validateXML($xml,[
            [
                'type' => 'x-im/instagram',
                'url' => 'https://www.instagram.com/p/BmPMCR3HLii/'
            ],
            [
                'type' => 'x-im/unknown',
                'url' => 'https://www.instagram.com/p/BmPMCR3HLii/'
            ],

        ]);
    }

    public function it_can_get_a_type()
    {
        $xml = '<link type="x-im/instagram" url="testat">test</link>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->getType($el)
            ->shouldReturn('x-im/instagram');
    }

    protected function validateXML($xml, array $matchValues): void
    {
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parseLinks($el)->shouldReturnValidItemCollection($matchValues);
    }
}
