<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\Metadata\ContactInfoParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PolygonParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PersonParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PositionParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;
use Infomaker\Everyware\NewsML\Parsers\MetaDataParser;
use Spec\Infomaker\Everyware\NewsML\CollectionParserSpec;

class MetaDataParserSpec extends CollectionParserSpec
{

    function let()
    {
        $objectParsers = [
            ContactInfoParser::OBJECT_TYPE => new ContactInfoParser(),
            PersonParser::OBJECT_TYPE => new PersonParser(),
            PolygonParser::OBJECT_TYPE => new PolygonParser(),
            PositionParser::OBJECT_TYPE => new PositionParser()
        ];
        $this->beConstructedWith(new ObjectParser($objectParsers));
    }

    function it_is_initializable()
    {
        $this->shouldHaveType(MetaDataParser::class);
    }

    public function it_should_return_contact_info()
    {
        $xml = <<<XML
<metadata>
    <object type="x-im/contact-info">
        <data>
            <email>test@mail.com</email>
            <phone>111222333</phone>
            <mobile>444555666</mobile>
        </data>
    </object>
</metadata>
XML;

        $this->validateXML($xml, [
            [
                'type' => 'x-im/contact-info',
                'email' => 'test@mail.com',
                'phone' => '111222333',
                'mobile' => '444555666',
            ]
        ]);
    }

    public function it_should_return_geometry()
    {
        $xml = <<<XML
<metadata>
    <object type="x-im/polygon">
    <data>
        <geometry>123.00.111</geometry>
    </data>
    </object>
</metadata>
XML;

        $this->validateXML($xml, [
            [
                'type' => 'x-im/polygon',
                'geometry' => '123.00.111',
            ]
        ]);
    }

    public function it_should_handle_no_data()
    {
        $xml = <<<XML
<metadata>
    <object type="x-im/polygon"/>
</metadata>

XML;

        $this->validateXML($xml, [
            [
                'type' => 'x-im/polygon'
            ]
        ]);

        $xml = <<<XML
<metadata>
    <object type="x-im/polygon">
        <data/>
    </object>
</metadata>
XML;

        $this->validateXML($xml, [
            [
                'type' => 'x-im/polygon'
            ]
        ]);
    }

    public function it_should_not_parse_unknown_object_types()
    {
        $xml = <<<XML
<metadata>
    <object type="x-im/unknown">
        <data>
            <email>test@mail.com</email>
            <phone>111222333</phone>
            <mobile>444555666</mobile>
        </data>
    </object>
</metadata>
XML;

        $this->validateXML($xml, []);
    }
}
