<?php declare(strict_types=1);

namespace Spec\Matchers;

use Infomaker\Everyware\NewsML\Item;
use PhpSpec\Exception\Example\FailureException;
use PhpSpec\Matcher\BasicMatcher;

/**
 * Class ValidItem
 * @package Spec\Matchers
 */
class ValidItemCollection extends BaseItemValidation
{
    private $names = [
        'beValidItemCollection',
        'returnValidItemCollection'
    ];

    /**
     * @param       $subject
     * @param array $arguments
     *
     * @return bool
     * @throws FailureException
     */
    protected function matches($subject, array $arguments): bool
    {
        $expectedResult = ! empty($arguments) ? $arguments[0] : [];
        $result = (array)$subject;

        if (empty($expectedResult) && ! empty($result)) {
            throw new FailureException(implode(PHP_EOL, [
                'Expected empty result',
                'but got',
                json_encode($result, JSON_PRETTY_PRINT)
                ])
            );
        }

        if ( ! empty($expectedResult) && empty($result)) {
            throw new FailureException(implode(PHP_EOL, [
                    'Did not return any parsed items',
                    'expected',
                    json_encode($expectedResult, JSON_PRETTY_PRINT)
                ])
            );
        }

        foreach ($expectedResult as $i => $expectedProperties) {
            $item = $result[$i] ?? null;
            if ( ! $item instanceof Item) {
                throw new FailureException(
                    sprintf('Failed to parse object into a "%s".', Item::class)
                );
            }

            $this->matchProperties($expectedProperties, $item->toArray());
        }

        return true;
    }

    protected function supportedNames(): array
    {
        return $this->names;
    }
}
